Check that mapped columns are present in all objects or none
check_column_all_or_none_mapped.RdCheck that mapped columns are present in all objects or none

check_column_all_or_none_mapped.RdCheck that mapped columns are present in all objects or none