Plot information factor or fraction over time for each hypothesis
plot_information.RdPlot information factor or fraction over time for each hypothesis
Usage
plot_information(config, time_grid = seq(0, 50, 1), use_fraction = FALSE)
plot_information.RdPlot information factor or fraction over time for each hypothesis
plot_information(config, time_grid = seq(0, 50, 1), use_fraction = FALSE)